@@ -65,7 +65,7 @@ sub unzip {
 
    my @files = ();
    for (@$lines) {
-      if (m{^\s*inflating:\s*([^\s]+)\s*$}) {
+      if (m{^\s*(?:inflating|extracting):\s*([^\s]+)\s*$}) {
          push @files, $1;
       }
    }
@@ -219,7 +219,7 @@ Metabrik::File::Compress - file::compress Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2020, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2022, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
